# mlda: A Python package for Machine Learning-based Data Assimilation

`mlda` is a Python package for Machine Learning-base Data Assimilation (DA).
It aims to provide a universal framework and the corresponding utilities for conducting reproducible DA experiments using novel machine learning-based DA methods.
